@@ -305,7 +305,12 @@ void PB_Cpgeadd( TYPE, DIRECA, DIRECC, CONJUG, M, N, ALPHA, A, IA, JA,
    }
 
    size   = TYPE->size; one = TYPE->one; zero = TYPE->zero;
+#ifdef FC_LEN_T
+   kb     = pilaenv_( &ctxt, C2F_CHAR( &TYPE->type ),
+                      (FC_LEN_T) strlen(C2F_CHAR( &TYPE->type )) );
+#else
    kb     = pilaenv_( &ctxt, C2F_CHAR( &TYPE->type ) );
+#endif
 
    Ainb1D = PB_Cfirstnb( ACnD, AiD, AinbD, AnbD );
    AnpD   = PB_Cnumroc( ACnD, 0, Ainb1D, AnbD, ACmyprocD, ArocD, ACnprocsD );
